@@ -15,6 +15,7 @@ from contextlib import contextmanager
 
 from celery.exceptions import NotRegistered
 from firexapp.discovery import get_all_pkg_versions_str
+from firexapp.engine.default_celery_config import primary_worker_minimum_concurrency
 from firexapp.engine.logging import add_hostname_to_log_records
 
 from firexkit.result import wait_on_async_results, disable_async_result, ChainRevokedException, \
@@ -34,6 +35,7 @@ from firexapp.submit.shutdown import launch_background_shutdown, DEFAULT_CELERY_
 from firexapp.submit.install_configs import load_new_install_configs, FireXInstallConfigs, INSTALL_CONFIGS_ENV_NAME
 from firexapp.submit.arguments import whitelist_arguments
 from firexapp.common import dict2str, silent_mkdir, create_link
+from firexapp.reporters.json_reporter import FireXJsonReportGenerator
 
 add_hostname_to_log_records()
 logger = setup_console_logging(__name__)
@@ -75,10 +77,25 @@ class OptionalBoolean(argparse.Action):
 
 class AdjustCeleryConcurrency(argparse.Action):
     def __call__(self, parser, namespace, values, option_string=None):
-        concurrency = max([values, 4])
+        concurrency = max([values, primary_worker_minimum_concurrency])
         setattr(namespace, self.dest, concurrency)
 
 
+def safe_create_completed_run_json(results, run_revoked, **kwargs):
+    try:
+        FireXJsonReportGenerator.create_completed_run_json(
+            root_id=results, run_revoked=run_revoked, **kwargs,
+        )
+    except Exception as e:
+        logger.error(f'Failed to generate completion run JSON: {e}')
+
+
+def safe_create_initial_run_json(**kwargs):
+    try:
+        FireXJsonReportGenerator.create_initial_run_json(**kwargs)
+    except Exception as e:
+        logger.error(f'Failed to generate initial run JSON: {e}')
+
 class SubmitBaseApp:
     SUBMISSION_LOGGING_FORMATTER = '[%(asctime)s %(levelname)s] %(message)s'
     DEFAULT_MICROSERVICE = None
@@ -307,6 +324,7 @@ class SubmitBaseApp:
             sys.exit(-1)
         self.wait_tracking_services_task_ready()
 
+        safe_create_initial_run_json(**chain_args)
         # AsyncResult objects cannot be in memory after the broker (i.e. backend) shutdowns, otherwise errors are
         # produced when they are garbage collected. We therefore monkey patch AsyncResults to track all instances
         # (e.g. from unpickle, instantiated directly, etc) so that disable_all_async_results can disable their
@@ -405,11 +423,12 @@ class SubmitBaseApp:
     def start_celery(self, args, plugins):
         from firexapp.celery_manager import CeleryManager
         celery_manager = CeleryManager(logs_dir=self.uid.logs_dir, plugins=plugins)
-        cpu_count = multiprocessing.cpu_count()
+        auto_scale_min = primary_worker_minimum_concurrency
+        auto_scale_max = multiprocessing.cpu_count()*8
         celery_manager.start(workername=app.conf.primary_worker_name,
                              wait=True,
                              concurrency=args.celery_concurrency,
-                             autoscale=None if args.celery_concurrency else (cpu_count, cpu_count*8),
+                             autoscale=None if args.celery_concurrency else (auto_scale_min, auto_scale_max),
                              soft_time_limit=args.soft_time_limit)
         self.celery_manager = celery_manager
 
@@ -528,12 +547,14 @@ class SubmitBaseApp:
     def self_destruct(self, chain_details=None, reason=None, run_revoked=False):
         if chain_details:
             chain_result, chain_args = chain_details
+            safe_create_completed_run_json(results=chain_result,
+                                           run_revoked=run_revoked,
+                                           **chain_args)
             try:
                 logger.debug("Generating reports")
                 from firexapp.submit.reporting import ReportersRegistry
                 ReportersRegistry.post_run_report(results=chain_result,
-                                                  kwargs=chain_args,
-                                                  run_revoked=run_revoked)
+                                                  kwargs=chain_args)
                 logger.debug('Reports successfully generated')
             except Exception:
                 # Under no circumstances should report generation prevent celery and broker cleanup
